pub fn recommended_blocksize<T: ComplexField>(
nrows: usize,
ncols: usize,
) -> usizeExpand description
the recommended block size to use for a $QR$ decomposition of a matrix with the given shape.
pub fn recommended_blocksize<T: ComplexField>(
nrows: usize,
ncols: usize,
) -> usizethe recommended block size to use for a $QR$ decomposition of a matrix with the given shape.